HNGPay class

Constructors

HNGPay()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applePay({required String amountToPay}) → dynamic
Displays an apple pay button on IOS device to handle payment
googlePay({required String amountToPay}) → dynamic
Displays a google pay button on Android device to handle payment
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited